# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
-   Add compatibility with PrimeVue 4 [#9](https://github.com/archesproject/arches-references/issues/9)
-   Add front-end routing [#4](https://github.com/archesproject/arches-references/issues/4)

### Changed
-   Generate URIs when not supplied [#8](https://github.com/archesproject/arches-references/issues/8)

### Fixed

### Deprecated

### Removed

### Security
